==> trilinos-15.0.0-3-x86_64.pkg.tar.zst: usr/lib/cmake/SEACASIoss/SEACASIossTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RELEASE".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "SEACASIoss::Ioss" for configuration "RELEASE"
set_property(TARGET SEACASIoss::Ioss APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(SEACASIoss::Ioss PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libIoss.so.15.0"
  IMPORTED_SONAME_RELEASE "libIoss.so.15"
  )

list(APPEND _cmake_import_check_targets SEACASIoss::Ioss )
list(APPEND _cmake_import_check_files_for_SEACASIoss::Ioss "${_IMPORT_PREFIX}/lib/libIoss.so.15.0" )

# Import target "SEACASIoss::Ioex" for configuration "RELEASE"
set_property(TARGET SEACASIoss::Ioex APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(SEACASIoss::Ioex PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libIoex.so.15.0"
  IMPORTED_SONAME_RELEASE "libIoex.so.15"
  )

list(APPEND _cmake_import_check_targets SEACASIoss::Ioex )
list(APPEND _cmake_import_check_files_for_SEACASIoss::Ioex "${_IMPORT_PREFIX}/lib/libIoex.so.15.0" )

# Import target "SEACASIoss::Ioexnl" for configuration "RELEASE"
set_property(TARGET SEACASIoss::Ioexnl APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(SEACASIoss::Ioexnl PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libIoexnl.so.15.0"
  IMPORTED_SONAME_RELEASE "libIoexnl.so.15"
  )

list(APPEND _cmake_import_check_targets SEACASIoss::Ioexnl )
list(APPEND _cmake_import_check_files_for_SEACASIoss::Ioexnl "${_IMPORT_PREFIX}/lib/libIoexnl.so.15.0" )

# Import target "SEACASIoss::Iopg" for configuration "RELEASE"
set_property(TARGET SEACASIoss::Iopg APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(SEACASIoss::Iopg PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libIopg.so.15.0"
  IMPORTED_SONAME_RELEASE "libIopg.so.15"
  )

list(APPEND _cmake_import_check_targets SEACASIoss::Iopg )
list(APPEND _cmake_import_check_files_for_SEACASIoss::Iopg "${_IMPORT_PREFIX}/lib/libIopg.so.15.0" )

# Import target "SEACASIoss::Ionull" for configuration "RELEASE"
set_property(TARGET SEACASIoss::Ionull APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(SEACASIoss::Ionull PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libIonull.so.15.0"
  IMPORTED_SONAME_RELEASE "libIonull.so.15"
  )

list(APPEND _cmake_import_check_targets SEACASIoss::Ionull )
list(APPEND _cmake_import_check_files_for_SEACASIoss::Ionull "${_IMPORT_PREFIX}/lib/libIonull.so.15.0" )

# Import target "SEACASIoss::Iovs" for configuration "RELEASE"
set_property(TARGET SEACASIoss::Iovs APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(SEACASIoss::Iovs PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libIovs.so.15.0"
  IMPORTED_SONAME_RELEASE "libIovs.so.15"
  )

list(APPEND _cmake_import_check_targets SEACASIoss::Iovs )
list(APPEND _cmake_import_check_files_for_SEACASIoss::Iovs "${_IMPORT_PREFIX}/lib/libIovs.so.15.0" )

# Import target "SEACASIoss::Iogn" for configuration "RELEASE"
set_property(TARGET SEACASIoss::Iogn APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(SEACASIoss::Iogn PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libIogn.so.15.0"
  IMPORTED_SONAME_RELEASE "libIogn.so.15"
  )

list(APPEND _cmake_import_check_targets SEACASIoss::Iogn )
list(APPEND _cmake_import_check_files_for_SEACASIoss::Iogn "${_IMPORT_PREFIX}/lib/libIogn.so.15.0" )

# Import target "SEACASIoss::Iotm" for configuration "RELEASE"
set_property(TARGET SEACASIoss::Iotm APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(SEACASIoss::Iotm PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libIotm.so.15.0"
  IMPORTED_SONAME_RELEASE "libIotm.so.15"
  )

list(APPEND _cmake_import_check_targets SEACASIoss::Iotm )
list(APPEND _cmake_import_check_files_for_SEACASIoss::Iotm "${_IMPORT_PREFIX}/lib/libIotm.so.15.0" )

# Import target "SEACASIoss::Iogs" for configuration "RELEASE"
set_property(TARGET SEACASIoss::Iogs APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(SEACASIoss::Iogs PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libIogs.so.15.0"
  IMPORTED_SONAME_RELEASE "libIogs.so.15"
  )

list(APPEND _cmake_import_check_targets SEACASIoss::Iogs )
list(APPEND _cmake_import_check_files_for_SEACASIoss::Iogs "${_IMPORT_PREFIX}/lib/libIogs.so.15.0" )

# Import target "SEACASIoss::Iohb" for configuration "RELEASE"
set_property(TARGET SEACASIoss::Iohb APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(SEACASIoss::Iohb PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libIohb.so.15.0"
  IMPORTED_SONAME_RELEASE "libIohb.so.15"
  )

list(APPEND _cmake_import_check_targets SEACASIoss::Iohb )
list(APPEND _cmake_import_check_files_for_SEACASIoss::Iohb "${_IMPORT_PREFIX}/lib/libIohb.so.15.0" )

# Import target "SEACASIoss::Iotr" for configuration "RELEASE"
set_property(TARGET SEACASIoss::Iotr APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(SEACASIoss::Iotr PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libIotr.so.15.0"
  IMPORTED_SONAME_RELEASE "libIotr.so.15"
  )

list(APPEND _cmake_import_check_targets SEACASIoss::Iotr )
list(APPEND _cmake_import_check_files_for_SEACASIoss::Iotr "${_IMPORT_PREFIX}/lib/libIotr.so.15.0" )

# Import target "SEACASIoss::Ionit" for configuration "RELEASE"
set_property(TARGET SEACASIoss::Ionit APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(SEACASIoss::Ionit PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libIonit.so.15.0"
  IMPORTED_SONAME_RELEASE "libIonit.so.15"
  )

list(APPEND _cmake_import_check_targets SEACASIoss::Ionit )
list(APPEND _cmake_import_check_files_for_SEACASIoss::Ionit "${_IMPORT_PREFIX}/lib/libIonit.so.15.0" )

# Import target "SEACASIoss::io_info_lib" for configuration "RELEASE"
set_property(TARGET SEACASIoss::io_info_lib APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(SEACASIoss::io_info_lib PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libio_info_lib.so.15.0"
  IMPORTED_SONAME_RELEASE "libio_info_lib.so.15"
  )

list(APPEND _cmake_import_check_targets SEACASIoss::io_info_lib )
list(APPEND _cmake_import_check_files_for_SEACASIoss::io_info_lib "${_IMPORT_PREFIX}/lib/libio_info_lib.so.15.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> trilinos-15.1.1-1-x86_64.pkg.tar.zst: usr/lib/cmake/SEACASIoss/SEACASIossTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RELEASE".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "SEACASIoss::Ioss" for configuration "RELEASE"
set_property(TARGET SEACASIoss::Ioss APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(SEACASIoss::Ioss PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libIoss.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libIoss.so.15"
  )

list(APPEND _cmake_import_check_targets SEACASIoss::Ioss )
list(APPEND _cmake_import_check_files_for_SEACASIoss::Ioss "${_IMPORT_PREFIX}/lib/libIoss.so.15.1.1" )

# Import target "SEACASIoss::Ioex" for configuration "RELEASE"
set_property(TARGET SEACASIoss::Ioex APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(SEACASIoss::Ioex PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libIoex.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libIoex.so.15"
  )

list(APPEND _cmake_import_check_targets SEACASIoss::Ioex )
list(APPEND _cmake_import_check_files_for_SEACASIoss::Ioex "${_IMPORT_PREFIX}/lib/libIoex.so.15.1.1" )

# Import target "SEACASIoss::Ioexnl" for configuration "RELEASE"
set_property(TARGET SEACASIoss::Ioexnl APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(SEACASIoss::Ioexnl PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libIoexnl.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libIoexnl.so.15"
  )

list(APPEND _cmake_import_check_targets SEACASIoss::Ioexnl )
list(APPEND _cmake_import_check_files_for_SEACASIoss::Ioexnl "${_IMPORT_PREFIX}/lib/libIoexnl.so.15.1.1" )

# Import target "SEACASIoss::Iopg" for configuration "RELEASE"
set_property(TARGET SEACASIoss::Iopg APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(SEACASIoss::Iopg PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libIopg.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libIopg.so.15"
  )

list(APPEND _cmake_import_check_targets SEACASIoss::Iopg )
list(APPEND _cmake_import_check_files_for_SEACASIoss::Iopg "${_IMPORT_PREFIX}/lib/libIopg.so.15.1.1" )

# Import target "SEACASIoss::Ionull" for configuration "RELEASE"
set_property(TARGET SEACASIoss::Ionull APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(SEACASIoss::Ionull PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libIonull.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libIonull.so.15"
  )

list(APPEND _cmake_import_check_targets SEACASIoss::Ionull )
list(APPEND _cmake_import_check_files_for_SEACASIoss::Ionull "${_IMPORT_PREFIX}/lib/libIonull.so.15.1.1" )

# Import target "SEACASIoss::Iovs" for configuration "RELEASE"
set_property(TARGET SEACASIoss::Iovs APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(SEACASIoss::Iovs PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libIovs.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libIovs.so.15"
  )

list(APPEND _cmake_import_check_targets SEACASIoss::Iovs )
list(APPEND _cmake_import_check_files_for_SEACASIoss::Iovs "${_IMPORT_PREFIX}/lib/libIovs.so.15.1.1" )

# Import target "SEACASIoss::Iogn" for configuration "RELEASE"
set_property(TARGET SEACASIoss::Iogn APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(SEACASIoss::Iogn PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libIogn.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libIogn.so.15"
  )

list(APPEND _cmake_import_check_targets SEACASIoss::Iogn )
list(APPEND _cmake_import_check_files_for_SEACASIoss::Iogn "${_IMPORT_PREFIX}/lib/libIogn.so.15.1.1" )

# Import target "SEACASIoss::Iotm" for configuration "RELEASE"
set_property(TARGET SEACASIoss::Iotm APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(SEACASIoss::Iotm PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libIotm.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libIotm.so.15"
  )

list(APPEND _cmake_import_check_targets SEACASIoss::Iotm )
list(APPEND _cmake_import_check_files_for_SEACASIoss::Iotm "${_IMPORT_PREFIX}/lib/libIotm.so.15.1.1" )

# Import target "SEACASIoss::Iogs" for configuration "RELEASE"
set_property(TARGET SEACASIoss::Iogs APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(SEACASIoss::Iogs PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libIogs.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libIogs.so.15"
  )

list(APPEND _cmake_import_check_targets SEACASIoss::Iogs )
list(APPEND _cmake_import_check_files_for_SEACASIoss::Iogs "${_IMPORT_PREFIX}/lib/libIogs.so.15.1.1" )

# Import target "SEACASIoss::Iohb" for configuration "RELEASE"
set_property(TARGET SEACASIoss::Iohb APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(SEACASIoss::Iohb PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libIohb.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libIohb.so.15"
  )

list(APPEND _cmake_import_check_targets SEACASIoss::Iohb )
list(APPEND _cmake_import_check_files_for_SEACASIoss::Iohb "${_IMPORT_PREFIX}/lib/libIohb.so.15.1.1" )

# Import target "SEACASIoss::Iotr" for configuration "RELEASE"
set_property(TARGET SEACASIoss::Iotr APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(SEACASIoss::Iotr PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libIotr.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libIotr.so.15"
  )

list(APPEND _cmake_import_check_targets SEACASIoss::Iotr )
list(APPEND _cmake_import_check_files_for_SEACASIoss::Iotr "${_IMPORT_PREFIX}/lib/libIotr.so.15.1.1" )

# Import target "SEACASIoss::Ionit" for configuration "RELEASE"
set_property(TARGET SEACASIoss::Ionit APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(SEACASIoss::Ionit PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libIonit.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libIonit.so.15"
  )

list(APPEND _cmake_import_check_targets SEACASIoss::Ionit )
list(APPEND _cmake_import_check_files_for_SEACASIoss::Ionit "${_IMPORT_PREFIX}/lib/libIonit.so.15.1.1" )

# Import target "SEACASIoss::io_info_lib" for configuration "RELEASE"
set_property(TARGET SEACASIoss::io_info_lib APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(SEACASIoss::io_info_lib PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libio_info_lib.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libio_info_lib.so.15"
  )

list(APPEND _cmake_import_check_targets SEACASIoss::io_info_lib )
list(APPEND _cmake_import_check_files_for_SEACASIoss::io_info_lib "${_IMPORT_PREFIX}/lib/libio_info_lib.so.15.1.1" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
